import { ɵɵdefineInjectable, Injectable, Component, ViewEncapsulation, ChangeDetectionStrategy, ElementRef, Optional, Inject, Input, NgModule } from '@angular/core';
import { DOCUMENT } from '@angular/common';

class FontAwesomeIconsRegistry {
    constructor() {
        this.registry = new Map();
    }
    registerIcons(icons) {
        icons.forEach((icon) => this.registry.set(icon.name, icon.data));
    }
    getIcon(iconName) {
        if (!this.registry.has(iconName)) {
            console.warn(`We could not find the dinosaur Icon with the name ${iconName}, did you add it to the Icon registry?`);
        }
        return this.registry.get(iconName);
    }
}
FontAwesomeIconsRegistry.ɵprov = ɵɵdefineInjectable({ factory: function FontAwesomeIconsRegistry_Factory() { return new FontAwesomeIconsRegistry(); }, token: FontAwesomeIconsRegistry, providedIn: "root" });
FontAwesomeIconsRegistry.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];

class FontAwesomeIconComponent {
    constructor(element, iconsRegistry, document) {
        this.element = element;
        this.iconsRegistry = iconsRegistry;
        this.document = document;
    }
    set name(iconName) {
        if (this.svgIcon) {
            this.element.nativeElement.removeChild(this.svgIcon);
        }
        const svgData = this.iconsRegistry.getIcon(iconName);
        if (svgData) {
            this.svgIcon = this.svgElementFromString(svgData);
            this.element.nativeElement.appendChild(this.svgIcon);
        }
    }
    svgElementFromString(svgContent) {
        const div = this.document.createElement('DIV');
        if (div instanceof HTMLElement) {
            div.innerHTML = svgContent;
            return div.querySelector('svg') || this.document.createElementNS('http://www.w3.org/2000/svg', 'path');
        }
    }
}
FontAwesomeIconComponent.decorators = [
    { type: Component, args: [{
                selector: 'font-awesome-icon',
                template: `<ng-content></ng-content>`,
                encapsulation: ViewEncapsulation.None,
                changeDetection: ChangeDetectionStrategy.OnPush
            },] }
];
FontAwesomeIconComponent.ctorParameters = () => [
    { type: ElementRef },
    { type: FontAwesomeIconsRegistry },
    { type: undefined, decorators: [{ type: Optional }, { type: Inject, args: [DOCUMENT,] }] }
];
FontAwesomeIconComponent.propDecorators = {
    name: [{ type: Input }]
};

class FontAwesomeIconsModule {
    static forRoot() {
        return {
            ngModule: FontAwesomeIconsModule,
            providers: [
                FontAwesomeIconsRegistry,
            ],
        };
    }
}
FontAwesomeIconsModule.decorators = [
    { type: NgModule, args: [{
                declarations: [FontAwesomeIconComponent],
                imports: [],
                exports: [FontAwesomeIconComponent]
            },] }
];

/*
 * Public API Surface of the icons lib
 */

/**
 * Generated bundle index. Do not edit.
 */

export { FontAwesomeIconComponent, FontAwesomeIconsModule, FontAwesomeIconsRegistry };
//# sourceMappingURL=triangular-font-awesome-icons.js.map
